==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_fr.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Ce doit être un bateau viking.")


dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Sûrement, c'est un drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Il a dû couler très vite. Les rameurs sont toujours à leur place.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Ils l'ont peut-être voulut. Les guerriers accompagnent toujours leur chef sur le chemin du Walhalla.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("C'est fou. On dirait qu'ils sont vivants.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("La musique est partie !")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Ils ont arrêté de jouer.")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("La musique s'arrête encore !")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("Oh, non !")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Encore ?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Oh, pas encore !")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Qu'est ce qui se passe ?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Encore ?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("Oh, non !")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("La musique sanglante s'est arrêtée.")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Qu'est-ce qu'ils font là haut ?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Comment il se peut ?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("C'est facile, les garçons. Un solo pour Olaf !")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Pas de problème, les garçons. nous pouvons chanter nous mêmes.")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Pas de problème, les garçons. nous pouvons chanter nous mêmes, comme au bon vieux temps.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_fr.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Ce doit être un bateau viking.")


dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Sûrement : c'est un drakkar.")


dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Il a dû couler très vite. Les rameurs sont toujours à leur place.")


dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Ils l'ont peut-être fait exprès. Les guerriers accompagnaient toujours leur chef sur le chemin du Walhalla.")


dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("C'est affreux. On dirait qu'ils sont toujours vivants.")


dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("La musique s'est arrêtée !")


dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Ils ne jouent plus.")


dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("La musique s'arrête encore !")


dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("Oh, non !")


dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Encore ?")


dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Oh, pas encore !")


dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Qu'est ce qui s'est passé ?")


dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Encore ?")


dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("Oh, non !")


dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Cette saleté de musique s'est arrêtée!")


dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Qu'est-ce qu'ils font là haut ?")


dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Comment est-ce possible ?")


dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("C'est facile, les garçons. Un solo pour Olaf !")


dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Pas de problème, les garçons. Nous pouvons chanter nous mêmes.")


dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Pas de problème, les garçons. Nous pouvons chanter nous mêmes, comme au bon vieux temps.")
